==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FinalValueLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { FinalValueLayerDescription } from "./FinalValueLayerDescription";
/**
 * @hidden
 */
export let FinalValueLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinalValueLayerDescriptionMetadata extends Base {
        static b(a) {
            if (FinalValueLayerDescriptionMetadata.a == null) {
                FinalValueLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinalValueLayerDescriptionMetadata.c(FinalValueLayerDescriptionMetadata.a);
            }
            if (a.j(FinalValueLayerDescriptionMetadata.a)) {
                return;
            }
            a.y(FinalValueLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetSeriesName", "String");
            a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
            a.item("FinalValueSelectionMode", "ExportedType:string:FinalValueSelectionMode");
            a.item("FinalValueSelectionMode@names", "Auto;FinalVisible;FinalVisibleInterpolated;Final");
            a.item("AxisAnnotationTextColor", "Brush");
            a.item("AxisAnnotationBackground", "Brush");
            a.item("AxisAnnotationBackgroundCornerRadius", "Number:double");
            a.item("AxisAnnotationInterpolatedValuePrecision", "Number:int");
            a.item("AxisAnnotationOutline", "Brush");
            a.item("AxisAnnotationPaddingLeft", "Number:double");
            a.item("AxisAnnotationPaddingTop", "Number:double");
            a.item("AxisAnnotationPaddingRight", "Number:double");
            a.item("AxisAnnotationPaddingBottom", "Number:double");
            a.item("AxisAnnotationStrokeThickness", "Number:double");
        }
        static d(a) {
            FinalValueLayerDescriptionMetadata.b(a);
            a.aa("FinalValueLayer", () => new FinalValueLayerDescription());
            a.z("FinalValueLayer", FinalValueLayerDescriptionMetadata.a);
        }
    }
    FinalValueLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(FinalValueLayerDescriptionMetadata, 'FinalValueLayerDescriptionMetadata');
    FinalValueLayerDescriptionMetadata.a = null;
    return FinalValueLayerDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FinalValueLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { FinalValueLayerDescription } from "./FinalValueLayerDescription";
/**
 * @hidden
 */
export let FinalValueLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinalValueLayerDescriptionMetadata extends Base {
        static b(a) {
            if (FinalValueLayerDescriptionMetadata.a == null) {
                FinalValueLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinalValueLayerDescriptionMetadata.c(FinalValueLayerDescriptionMetadata.a);
            }
            if (a.k(FinalValueLayerDescriptionMetadata.a)) {
                return;
            }
            a.aa(FinalValueLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetSeriesName", "String");
            a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
            a.item("FinalValueSelectionMode", "ExportedType:string:FinalValueSelectionMode");
            a.item("FinalValueSelectionMode@names", "Auto;FinalVisible;FinalVisibleInterpolated;Final");
            a.item("AxisAnnotationTextColor", "Brush");
            a.item("AxisAnnotationBackground", "Brush");
            a.item("AxisAnnotationBackgroundCornerRadius", "Number:double");
            a.item("AxisAnnotationInterpolatedValuePrecision", "Number:int");
            a.item("AxisAnnotationOutline", "Brush");
            a.item("AxisAnnotationPaddingLeft", "Number:double");
            a.item("AxisAnnotationPaddingTop", "Number:double");
            a.item("AxisAnnotationPaddingRight", "Number:double");
            a.item("AxisAnnotationPaddingBottom", "Number:double");
            a.item("AxisAnnotationStrokeThickness", "Number:double");
        }
        static d(a) {
            FinalValueLayerDescriptionMetadata.b(a);
            a.ac("FinalValueLayer", () => new FinalValueLayerDescription());
            a.ab("FinalValueLayer", FinalValueLayerDescriptionMetadata.a);
        }
    }
    FinalValueLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(FinalValueLayerDescriptionMetadata, 'FinalValueLayerDescriptionMetadata');
    FinalValueLayerDescriptionMetadata.a = null;
    return FinalValueLayerDescriptionMetadata;
})();
